activity_streams v0.1.0 ActivityStreams.Properties.StartTime View Source
The date and time describing the actual or expected starting time of the object. When used with an Activity object, for instance, the startTime property specifies the moment the activity began or is scheduled to begin. W3C
Examples
{“@context”:”https://www.w3.org/ns/activitystreams”,”type”:”Event”,”name”:”Going-Away Party for Jim”,”startTime”:”2014-12-31T23:00:00-08:00”,”endTime”:”2015-01-01T06:00:00-08:00”}